@@ -1,4 +1,10 @@
 package Tapper::Schema::ReportsDB::Result::ReportTopic;
+BEGIN {
+  $Tapper::Schema::ReportsDB::Result::ReportTopic::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::ReportsDB::Result::ReportTopic::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -22,10 +28,15 @@ __PACKAGE__->belongs_to   ( report => 'Tapper::Schema::ReportsDB::Result::Report
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::ReportsDB::ReportTopic - A ResultSet description
-
+Tapper::Schema::ReportsDB::Result::ReportTopic
 
 =head1 SYNOPSIS
 
@@ -33,20 +44,35 @@ Abstraction for the database table.
 
  use Tapper::Schema::ReportsDB;
 
+=head1 NAME
+
+Tapper::Schema::ReportsDB::ReportTopic - A ResultSet description
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
