@@ -1,4 +1,10 @@
 package Tapper::Schema::ReportsDB::Result::Tap;
+BEGIN {
+  $Tapper::Schema::ReportsDB::Result::Tap::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::ReportsDB::Result::Tap::VERSION = '4.0.1';
+}
 
 use 5.010;
 use strict;
@@ -30,3 +36,27 @@ __PACKAGE__->set_primary_key("id");
 __PACKAGE__->belongs_to   ( report => 'Tapper::Schema::ReportsDB::Result::Report', { 'foreign.id' => 'self.report_id' });
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Schema::ReportsDB::Result::Tap
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
