@@ -1,4 +1,10 @@
 package Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports;
+BEGIN {
+  $Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports::VERSION = '4.0.1';
+}
 # the number is to sort classes on deploy
 
 use 5.010;
@@ -31,3 +37,27 @@ __PACKAGE__->add_columns
     );
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Schema::ReportsDB::Result::View010TestrunOverviewReports
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
