@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::Result::HostFeature;
+BEGIN {
+  $Tapper::Schema::TestrunDB::Result::HostFeature::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::Result::HostFeature::VERSION = '4.0.1';
+}
 
 use 5.010;
 use strict;
@@ -29,27 +35,47 @@ __PACKAGE__->belongs_to( host => "${basepkg}::Host", { 'foreign.id' => 'self.hos
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::HostFeature - A ResultSet description
-
+Tapper::Schema::TestrunDB::Result::HostFeature
 
 =head1 SYNOPSIS
 
+=head1 NAME
+
+Tapper::Schema::TestrunDB::Result::HostFeature - A ResultSet description
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
