@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::Result::Message;
+BEGIN {
+  $Tapper::Schema::TestrunDB::Result::Message::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::Result::Message::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -10,8 +16,9 @@ __PACKAGE__->load_components(qw/InflateColumn::DateTime Core InflateColumn/);
 __PACKAGE__->table("message");
 __PACKAGE__->add_columns
     ( "id",        { data_type => "INT",       default_value => undef,                is_nullable => 0, size => 11, is_auto_increment => 1, },
-     "testrun_id", { data_type => "INT",       default_value => undef,                is_nullable => 0, size => 11, is_foreign_key    => 1, },
+     "testrun_id", { data_type => "INT",       default_value => undef,                is_nullable => 1, size => 11, is_foreign_key    => 1, },
      "message",    { data_type => "VARCHAR",   default_value => undef,                is_nullable => 1, size => 65000, },
+     "type",       { data_type => "VARCHAR",   is_nullable => 1, size => 255, is_enum => 1, extra => { list => [qw(action state)] } },
      "created_at", { data_type => "TIMESTAMP", default_value => \'CURRENT_TIMESTAMP', is_nullable => 1, },
      "updated_at", { data_type => "DATETIME",  default_value => undef,                is_nullable => 1, },
     );
@@ -25,10 +32,17 @@ __PACKAGE__->inflate_column( message => {
 __PACKAGE__->set_primary_key("id");
 __PACKAGE__->belongs_to( testrun => "${basepkg}::Testrun", { 'foreign.id' => 'self.testrun_id' });
 
+
+1;
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Message - Keep messages received for testruns.
-
+Tapper::Schema::TestrunDB::Result::Message
 
 =head1 SYNOPSIS
 
@@ -36,23 +50,35 @@ Abstraction for the database table.
 
  use Tapper::Schema::TestrunDB;
 
+=head1 NAME
+
+Tapper::Schema::TestrunDB::Result::Message - Keep messages received for testruns.
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
 =cut
 
-1;
