@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::Result::Scenario;
+BEGIN {
+  $Tapper::Schema::TestrunDB::Result::Scenario::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::Result::Scenario::VERSION = '4.0.1';
+}
 
 use 5.010;
 use strict;
@@ -23,10 +29,15 @@ __PACKAGE__->has_many  ( scenario_elements => "${basepkg}::ScenarioElement", { '
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::Testgroup - Grouping of interdependent tests  
-
+Tapper::Schema::TestrunDB::Result::Scenario
 
 =head1 SYNOPSIS
 
@@ -34,20 +45,35 @@ Abstraction for the database table.
 
  use Tapper::Schema::TestrunDB;
 
+=head1 NAME
+
+Tapper::Schema::TestrunDB::Result::Testgroup - Grouping of interdependent tests
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
