@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::Result::State;
+BEGIN {
+  $Tapper::Schema::TestrunDB::Result::State::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::Result::State::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -6,7 +12,7 @@ use warnings;
 use parent 'DBIx::Class';
 use YAML::Syck;
 
-__PACKAGE__->load_components(qw/InflateColumn::DateTime Core/);
+__PACKAGE__->load_components(qw/InflateColumn::DateTime InflateColumn::Object::Enum Core/);
 __PACKAGE__->table("state");
 __PACKAGE__->add_columns
     ( "id",        { data_type => "INT",       default_value => undef,                is_nullable => 0, size => 11, is_auto_increment => 1, },
@@ -27,10 +33,17 @@ __PACKAGE__->set_primary_key("id");
 __PACKAGE__->add_unique_constraint( unique_testrun_id => [ qw/testrun_id/ ], );
 __PACKAGE__->belongs_to( testrun => "${basepkg}::Testrun", { 'foreign.id' => 'self.testrun_id' });
 
+
+1;
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::State - A ResultSet description
-
+Tapper::Schema::TestrunDB::Result::State
 
 =head1 SYNOPSIS
 
@@ -38,23 +51,35 @@ Abstraction for the database table.
 
  use Tapper::Schema::TestrunDB;
 
+=head1 NAME
+
+Tapper::Schema::TestrunDB::Result::State - A ResultSet description
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
 =cut
 
-1;
