@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::Result::TestrunRequestedHost;
+BEGIN {
+  $Tapper::Schema::TestrunDB::Result::TestrunRequestedHost::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::Result::TestrunRequestedHost::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -11,7 +17,7 @@ __PACKAGE__->add_columns
     (
      "id",              { data_type => "INT",     default_value => undef, is_nullable => 0, size => 11, is_auto_increment => 1, },
      "testrun_id",      { data_type => "INT",     default_value => undef, is_nullable => 0, size => 11, is_foreign_key    => 1, },
-     "host_id",         { data_type => "INT",     default_value => undef,    is_nullable => 1,                                     },
+     "host_id",         { data_type => "INT", default_value => undef, is_nullable => 0, size => 11, is_foreign_key    => 1, },
     );
 
 __PACKAGE__->set_primary_key(qw/id/);
@@ -23,10 +29,15 @@ __PACKAGE__->belongs_to( host              => "${basepkg}::Host",    { 'foreign.
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::TestrunDB::Result::PrePrecondition - A ResultSet description
-
+Tapper::Schema::TestrunDB::Result::TestrunRequestedHost
 
 =head1 SYNOPSIS
 
@@ -34,20 +45,35 @@ Abstraction for the database table.
 
  use Tapper::Schema::TestrunDB;
 
+=head1 NAME
+
+Tapper::Schema::TestrunDB::Result::PrePrecondition - A ResultSet description
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
