@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::Result::Topic;
+BEGIN {
+  $Tapper::Schema::TestrunDB::Result::Topic::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::Result::Topic::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -30,10 +36,15 @@ __PACKAGE__->set_primary_key("name");
 
 1;
 
+
+__END__
+=pod
+
+=encoding utf-8
+
 =head1 NAME
 
-Tapper::Schema::TestsDB::Topic - A ResultSet description
-
+Tapper::Schema::TestrunDB::Result::Topic
 
 =head1 SYNOPSIS
 
@@ -41,20 +52,35 @@ Abstraction for the database table.
 
  use Tapper::Schema::TestrunDB;
 
+=head1 NAME
+
+Tapper::Schema::TestsDB::Topic - A ResultSet description
 
 =head1 AUTHOR
 
 AMD OSRC Tapper Team, C<< <tapper at amd64.org> >>
 
-
 =head1 BUGS
 
 None.
 
-
 =head1 COPYRIGHT & LICENSE
 
 Copyright 2008-2011 AMD OSRC Tapper Team, all rights reserved.
 
 This program is released under the following license: freebsd
 
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
