@@ -1,4 +1,10 @@
 package Tapper::Schema::TestrunDB::ResultSet::Precondition;
+BEGIN {
+  $Tapper::Schema::TestrunDB::ResultSet::Precondition::AUTHORITY = 'cpan:AMD';
+}
+{
+  $Tapper::Schema::TestrunDB::ResultSet::Precondition::VERSION = '4.0.1';
+}
 
 use strict;
 use warnings;
@@ -31,3 +37,32 @@ sub add {
 }
 
 1;
+
+__END__
+=pod
+
+=encoding utf-8
+
+=head1 NAME
+
+Tapper::Schema::TestrunDB::ResultSet::Precondition
+
+=head2 add
+
+Create (add) a list of preconditions and return them with their now
+associated db data (eg. ID).
+
+=head1 AUTHOR
+
+AMD OSRC Tapper Team <tapper@amd64.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2012 by Advanced Micro Devices, Inc..
+
+This is free software, licensed under:
+
+  The (two-clause) FreeBSD License
+
+=cut
+
